(function ($, Drupal, drupalSettings, once) {
  'use strict';

  Drupal.behaviors.contentSaveConfirm = {
    attach: function (context, settings) {
      // Debug: Check if settings are available
      if (typeof drupalSettings.contentSaveConfirm === 'undefined') {
        console.log('Content Save Confirm: Settings not found');
        return;
      }

      // Find forms with the content-save-confirm-form class using once
      once('content-save-confirm', '.content-save-confirm-form', context).forEach(function (form) {
        var $form = $(form);
        var confirmSettings = drupalSettings.contentSaveConfirm;
        
        console.log('Content Save Confirm: Attaching to form', $form.attr('id'));
        console.log('Content Save Confirm: Settings', confirmSettings);
        
        // Find submit buttons - be more specific about which buttons to target
        var $submitButtons = $form.find('input[type="submit"], button[type="submit"]');
        
        console.log('Content Save Confirm: Found buttons', $submitButtons.length);
        
        // Add click handler to submit buttons
        $submitButtons.each(function() {
          var $button = $(this);
          var buttonValue = $button.val() || $button.text() || $button.attr('data-drupal-selector') || '';
          
          console.log('Content Save Confirm: Button found', buttonValue);
          
          // Skip confirmation for certain buttons (like preview, delete, etc.)
          var skipConfirmation = /preview|delete|cancel|remove|draft/i.test(buttonValue);
          
          if (!skipConfirmation) {
            console.log('Content Save Confirm: Adding handler to button', buttonValue);
            
            $button.on('click.content-save-confirm', function (e) {
              console.log('Content Save Confirm: Button clicked', buttonValue);
              
              // Prevent default form submission
              e.preventDefault();
              e.stopImmediatePropagation();
              
              // Show confirmation dialog
              var confirmed = confirm(confirmSettings.message);
              console.log('Content Save Confirm: User confirmed?', confirmed);
              
              if (confirmed) {
                // If confirmed, remove our handler and submit
                $button.off('click.content-save-confirm');
                
                // Create a new click event to trigger original handlers
                var clickEvent = new MouseEvent('click', {
                  bubbles: true,
                  cancelable: true,
                  view: window
                });
                
                // Dispatch the event to trigger form submission
                $button[0].dispatchEvent(clickEvent);
              }
              
              return false;
            });
          }
        });
      });
    }
  };

})(jQuery, Drupal, drupalSettings, once);